@@ -52,11 +52,19 @@ def get_nyse(as_list=True): # Test to see if duplicate tickers on backend or Dja
         df = df.reset_index()
         df = df['Symbol']
         dfs.append(df)
-  
-	# Will this work since they are series?
+        
+    for letter in 'abcdefghijklmnopqrstuvwxyz':       
+        request = get(f'https://eoddata.com/stocklist/NYSE/{letter}.htm')
+        soup = BeautifulSoup(request.text, 'lxml')
+        table = soup.find('table', {'class': 'quotes'})
+        df = pd.read_html(str(table))[0]
+        df = df['Code']
+        dfs.append(df)
+        
+    	# Will this work since they are series?
     df = pd.concat(dfs)
     df = df.reset_index()
-    df = df['Symbol']
+    df = df[0]
     if as_list:
         return sorted(df.tolist())
     return df.sort_values(ascending=True)
